.. django-partitialajax documentation master file, created by
   sphinx-quickstart on Sun Dec 22 00:49:10 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-partitialaja's documentation!
===============================================

Last Version 0.2.2

.. toctree::
   :maxdepth: 2
   :caption: General:

   general/installation
   general/information
   general/jsonprotocol
   general/templatetags
   general/usage

.. toctree::
   :maxdepth: 2
   :caption: Code:

   code/mixin
   code/js
   code/templatetag



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
